# Database

Classes and functions to interact with databases of publications.


## Models

Abstract description of GisMap DB interface.

```{eval-rst}
.. automodule:: gismap.sources.models
    :members:
```

## LDB (Local DBLP)

Interface for *dblp computer science bibliography* (https://dblp.org/) using a local copy of the database.

```{eval-rst}
.. automodule:: gismap.sources.ldb
    :members:
```


```{eval-rst}
.. automodule:: gismap.sources.dblp_ttl
    :members:
```


## DBLP (online)

Interface for *dblp computer science bibliography* (https://dblp.org/).

```{eval-rst}
.. automodule:: gismap.sources.dblp
    :members:
```

## HAL

Interface for *HyperArticles en Ligne* (https://hal.science/).

```{eval-rst}
.. automodule:: gismap.sources.hal
    :members:
```

## Multi-source

Interface for handling multiple sources at once.

```{eval-rst}
.. automodule:: gismap.sources.multi
    :members:
```
